Rummage - Rummage

# Rummage

## Overview

Rummage is a cross platform search and replace tool. Rummage crawls directories and searches for specified patterns (either regular expression or literal) and can optionally replace those targets with desired text.

Rummage is written in Python and is currently available on Python 3. Rummage by default uses Python's Re regular expression engine, but you can also use the fantastic, feature rich Regex search engine and do interesting things like fuzzy searching and more.